@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(get sections);
 Readonly::Scalar my $EMPTY_STR => q{};
 
-our $VERSION = 0.1;
+our $VERSION = 0.11;
 
 # Get content for file or module.
 sub get {
@@ -68,16 +68,16 @@ sub _get_content {
 	foreach my $child ($pod_section->children) {
 		if ($child->type eq 'begin') {
 
-			# Skip =begin html
-			if ($child->body =~ m/^html/ms) {
-				next;
-
 			# =begin text as commented text.
-			} elsif ($child->body =~ m/^text/ms) {
+			if ($child->body =~ m/^text/ms) {
 				$child_pod .= join "\n",
 					map { ' #'.$_ }
 					split m/\n/ms,
 					($child->children)[0]->pod;
+
+			# Skip =begin html and other unsupported sections.
+			} else {
+				next;
 			}
 		} else {
 			$child_pod .= $child->pod;
@@ -293,6 +293,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.1
+0.11
 
 =cut
